/**     Pamesport Mobile Application.
 *      Core controller which handles and manages all application operations.
 *      @class          app
 *      @extends        
 *      @file           www/js/index.php
 *      @package        Telia.Mobile.Pamesports
 *      @author         Joseph Carras
 *      @date           Thursday, January 9, 2014
 *      @version        1.0.0
 *      @copyright      Copyright (C) 2010 - 2013 InnviWeb, Inc. All rights reserved.
 *      @license        GNU General Public License version 2 or later; see LICENSE.txt
 */


// ------- Namespace Declaration ----------------------------------------------------------------------
var app = { };
// ------- End of Namespace Declaration ---------------------------------------------------------------

// ------- Application Setting Declarations -----------------------------------------------------------
app.ajax = {
    type: "GET",
    url: "http://www.pamesports.gr/jsonrpc/",
    cache: true,
    dataType: "json",
    timeout: 10000,
    data: {"json": "true"},
    beforeSend: function() {
        app.info( 'AJAX CALL' );
    },
    error: function (request, status) {
        app.warrning ('Please check your internet connection...');
        app.info ('AJAX Failed for ' + this.url + ' status ' + status );
//        device.exitApp();
    },
},

app.loading = {
    text: 'Please wait...',
    textVisible: true,
    theme: 'a',
    html: ""
},
// ------- End of Application Setting Declarations ----------------------------------------------------

// ------- Public Class Member Definitions ------------------------------------------------------------
app.deviceReady = $.Deferred ().resolve();
app.mobileInit = $.Deferred ();
//app.backButton = false;
app.pageId = 'home';
app.categoryId = null;
app.articleId = null;
// ------- End of Public Class Member Definitions -----------------------------------------------------

$(document).one( 'deviceready', function () { app.deviceReady.resolve (); } );

// ------- Class Debuging Function Implementation -----------------------------------------------------
app.info = function ($msg) {
    console.log ($msg);
};

app.warrning = function ($msg) {
    navigator.notification.alert($msg, function () { }, "Πρόβλημα" , "");
};

app.error = function ($msg) {
    $msg = 'There has been an error. Please load again.';
    navigator.notification.alert($msg, function () { }, "Error", "");
};
// ------- End of Class Debuggin Function Implementation ----------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.decodeEntities = (function() {
    var element = document.createElement('div');
    function decode (str) {
        if(str && typeof str === 'string') {
            str = str.replace(/<script[^>]*>([\S\s]*?)<\/script>/gmi, '');
            str = str.replace(/<\/?\w(?:[^"'>]|"[^"]*"|'[^']*')*>/gmi, '');
            element.innerHTML = str; str = element.textContent; element.textContent = '';
        }
        return str;
    }
    return decode;
})();
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.parameter = function ($name) {
    $temp = RegExp($name + '=' + '(.+?)(&|$)').exec(location.search);
    return $temp ? decodeURI ($temp [1]) : null;
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.isSet = function ($prop) {
    var proto = app.__proto__ || app.constructor.prototype;
    return ($prop in app) && (!($prop in proto) || proto[$prop] !== app[$prop]);
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.camelCase = function ($string) {
    return $string.charAt(0).toUpperCase() + $string.slice(1).toLowerCase();
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.getType = function ($obj) {
    return ({}).toString.call($obj).match(/\s([a-zA-Z]+)/)[1].toLowerCase();
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.storage = function ($id, $data, $ttl) {
    $data = typeof $data !== 'undefined' ? $data : null;
    $ttl  = typeof $ttl  !== 'undefined' ? parseInt ($ttl) : 0;

    if (typeof $id == 'string' || $id instanceof String) { }
    else { app.error ('Storage id type is invalid [' + app.getType ($id) + ']'); return null; }

    if ($data !== null) {
        app.info ('Set storage data with id ' + $id);
        if ($ttl) { $ttl = new Date (new Date ().getTime() + $ttl * 60000).getTime(); }
        return localStorage.setItem ($id, JSON.stringify({ttl: $ttl, data: $data}) );
    } else if ($data = localStorage.getItem ($id) ) { $data = JSON.parse($data); }
    else { return null; }

    if ( ($data.ttl === 0) || ($data.ttl > new Date().getTime() ) ) {
        app.info ('Get storage data with id ' + $id); return $data.data;
    } else { app.info ('Expired storage data with id ' + $id); return null; }
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.initialize = function () {
    this.info ('Initialize Application');
    if ($pageId = app.parameter ('page') ) { this.pageId = $pageId.toLowerCase (); }

    //$func = 'get' + app.camelCase (app.pageId);
    //if (app.isSet ($func) ) { app[$func](); }
    //else { app.error ('Invalid class method [' + $func + ']'); }

    $(document).one ('mobileinit' , function () {
        $.mobile.defaultPageTransition = 'fade';
        //$.mobile.page.prototype.options.addBackBtn = true;
        window.location.hash = app.pageId;
        app.mobileInit.resolve ();
    });

    $(document).one ('pagebeforeshow', function(e , ui) {
//        $("div:jqmData(role='content')").css("min-height", function(){ return $(this).height(); });
//        $("div:jqmData(role='content')").css("min-height", window.innerHeight);
        $.when(app.deviceReady).then (function() {
            if( navigator.splashscreen ) { navigator.splashscreen.hide(); }
        });
    }); 

    $(document).on ('ajaxSend', function () {
        //$(":mobile-pagecontainer").pagecontainer("getActivePage").children("#copyright)").hide();
        //if ($page = $.mobile.activePage) { $page.first(".copyright)").hide(); }
        //$(".copyright").hide();

        $(document).one ('pageshow', function(e , ui) {
            if ($.active) { $.mobile.loading('show', app.loading) }; 
        });
    });

    $(document).on ('ajaxComplete', function(e , ui) {
        //$(":mobile-pagecontainer").pagecontainer("getActivePage").children("#copyright)").show();
        //$.mobile.activePage.first(".copyright)").show();
        //$(".copyright").show();
        $.mobile.loading('hide');
    });

    $(document).on ('pageinit', '#home', function(e , ui) {
        if ($result = app.storage ('#home') ) { app.setHome ($result); }
        else { app.getHome (); }
    });

    $(document).on ('pagebeforeshow', '#home', function(e , ui) {
        if ($result = app.storage ('#home') ) { } else { app.getHome (); }
    });

    $(document).on ('pageinit', '#categories', function(e , ui) {
        if ($result = app.storage ('#categories') ) { app.setCategories ($result); }
        else { app.getCategories (); }
    });

    $(document).on ('pagebeforeshow', '#categories', function(e , ui) {
        if ($result = app.storage ('#categories') ) { } else { app.getCategories (); }
    });
/*
    $(document).on ('vclick', '.back-button', function(e , ui) {
        $.mobile.back();
    });
*/
    $(document).on ('vclick', 'a[data-article]', function(e , ui) {
        if ($(this).attr('href') == '#') { return false; }
        app.getArticle ($(this).data ('article'), '1');
    });

    $(document).on ('vclick', 'a[data-category]', function(e , ui) {
        app.getCategory ($(this).data ('category'), '1');
    });

    $(document).on ('vclick', '#ssearch', function(e , ui) {
        var searchstr = $("#searchinput").val();
        if(searchstr.length > 2) { app.getSearch (searchstr); }
        else { app.warrning ("Εισάγετε λέξη αναζήτησης με πάνω απο δύο χαρακτήρες"); return false; }
    });

    $(document).on ('vclick', '#commentsWrapper .commentImage img', function(e , ui) {
        $src = $(this).attr('src'); $src = $src.replace('_t','_n');
        $.when(app.mobileInit).then (function () {
            var ref = window.open($src, '_blank', 'location=yes');
        });
        return false;
    });

    $(document).on ('vclick', '.copyright a', function(e , ui) {
        $href = $(this).attr('href');
        $.when(app.deviceReady).then (function () {
            var ref = window.open($href, '_blank', 'location=yes');
        });
        return false;
    });

    $(document).on('pagebeforechange', '[data-role=footer]', function() { $(this).hide(); });
    $(document).on('pagechange', '[data-role=footer]', function() { $(this).show(); });
/*
    $("div[data-role='page']").one ('pageshow', function height(e , ui) {
		if ( typeof height.init == 'undefined' ) {
            height.window = $(window).height();
            height.copyright = $('.copyright:first').height();
            height.init = true;
        }
        $header = $(this).find('.header').height();
        $val = height.window -  ($header + height.copyright + 40);
        $(this).find("[data-role='content']").css("min-height", $val);
    });
*/

    //$.when(app.mobileInit).then (this.launch);
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.getHome = function(){
    app.info ('Get Home Content');

    $.ajax($.extend(true, {}, app.ajax, {
        data: {"method": "getSliderArticles", "params":["1","0","20"], id:"2"},
        success: function(result) {
            app.storage ('#home', result, 5);
            app.info ('URL:' + this.url);
            app.info (result);
            $.when(app.deviceReady).then (function(){ app.setHome(result); }); 
        }
    }));
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.getCategories = function () {
    app.info ('Get Categories Content');
    $.ajax($.extend(true, {}, app.ajax, {
        data: {"method": "getCategories", "params":["1"], id:"2"},
        success: function(result) {
            app.info ('URL:' + this.url);
            app.info (result);
            $.when(app.deviceReady).then (function(){
                app.setCategories (result);
                $.mobile.loading('hide');
                app.storage ('#categories', result, 720);
            }); 
        }
    }));
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.getCategory = function ($id, $lang) {
    app.info ('Get Category Content for id ' + $id);
    $('#category-content').empty();

    var $cache = app.storage( 'category_' + $id + '_' + $lang );

    if( $cache ) {
        setTimeout( function(){ app.setCategory( $cache ); }, 500);
        return;
    }

    $.ajax($.extend(true, {}, app.ajax, {
        data: {"jsonrpc": "2.0", "method": "getArticles", "params":["1",$id, "0", "20"], $id:"2"},
        cache: true,
        success: function(result) {
            app.info ('URL:' + this.url);
            app.info (result);
            $.when(app.deviceReady).then (function(){
                app.storage( 'category_' + $id + '_' + $lang, result,  5 );
                app.setCategory( result );
            });
        }
    }));
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.getSearch = function ($string) {
    app.info ('Get Search Content for string ' + $string);

    $('#category-content').empty();

    $.ajax($.extend(true, {}, app.ajax, {
        data: {"method": "getResults", "params":[$string],id:"2"},
        cache: true,
        success: function(result) {
            app.info (result);
            $tmp = result.result;
            if (typeof $tmp == 'string' || $tmp instanceof String) {
                $('#category-content').html($tmp);
            } else { $.when(app.deviceReady).then (function(){ app.setCategory (result); }); }
        }
    }));
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.getArticle = function ($id, $lang) {
    app.info ('Get Article Content for id ' + $id);

    $('#article_title').html("");
    $('#article_photo').html("");
    $('#article_desc').html("");
    $('#article_video').html("");

    var $cache = app.storage( 'article_' + $id + '_' + $lang );

    if( $cache ) {
        setTimeout( function(){ app.setArticle( $cache ); }, 500);
        return;
    }

    $.ajax($.extend(true, {}, app.ajax, {
        data: {"method": "getArticle", "params":[$id, $lang],id:"2"},
        cache: true,
        success: function(result) {
            app.info ('URL:' + this.url);
            app.info (result);
            $.when(app.deviceReady).then (function(){
                app.storage( 'article_' + $id + '_' + $lang, result,  30 );
                app.setArticle (result);
            });
        }
    }));
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.setHome = function(data){
    app.info ('Set Home Content');
    var level = 0;
    var counter = 0;
    //var items = '<li data-role="list-divider" role="heading">Άρθρα</li>';
    var items = '';
    var linkstr = '';
    var smalldesc = '';
    var video = '';
    var pdf = '';
    var photo = '';
    var cnt_date = '';
    var photostr = '';

    while (counter < data.result.length){
        $content = data.result [counter];

        //cnt_date = $content['cnt_date'];
        smalldesc = $content['page_description'];

        if(smalldesc == null){ smalldesc = ""; }
        //else { smalldesc = "<span class='smalldesc'> "+ smalldesc + "</span>"; }

        video = $content['youtubeid'];
        pdf = $content['pdf'];
        photo = $content['photo'];

        if(photo != ""){
            //photostr = "http://www.pamesports.gr/thumbnail?filepath="+photo+"&width=290";
            photostr = "http://www.pamesports.gr/thumbnail?filepath="+photo+"&width=160";
            //linkstr = '#content?id='+$content['page_id'];
            //linkstr = 'javascript:changeArticle('+$content['page_id']+')';
            //linkstr = '#article?id=' + $content['page_id'];
            linkstr = '#article';
        } else { 
            //http://pamesports.gr/templates/el/images/no_photo.jpg
             photostr = "http://www.pamesports.gr/thumbnail?filepath=http://pamesports.gr/templates/el/images/no_photo.jpg&width=160";
            linkstr = '#article';
        }
        
        if(photo == null && video != null){
            photostr = "http://img.youtube.com/vi/"+video+"/hqdefault.jpg";
            linkstr = "javascript:window.plugins.childBrowser.openExternal('http://www.youtube.com/watch?v="+video+"');";
        }
        
        if(pdf != null){
            //photostr = "http://www.pamesports.gr/thumbnail?filepath="+photo+"&width=290";
            photostr = "http://www.pamesports.gr/thumbnail?filepath="+photo+"&width=160";
            linkstr = "javascript:window.plugins.childBrowser.openExternal('http://www.xrimaonline.gr/"+pdf+"');";
        }

        //items += '<li  data-icon="false"><a href="'+linkstr+'"><h2 class="ui-li-heading" style="white-space:normal">'+$content['page_title']+'</h2><p><img src="'+photostr+'" width="290"/></p><p class="ui-li-desc" style="white-space:normal">'+smalldesc+'</p></a></li>';
        //items += '<li data-icon="false"><a href="'+linkstr+'"><h2 class="ui-li-heading" style="white-space:normal">'+$content['page_title']+' <span class="arthrografos"><span class="lektika">Κατηγορία: </span>'+$content['cat_title']+'</span>'+cnt_date+smalldesc+'</h2>'+'<p  style="white-space:normal">'+'<img src="'+photostr+'" width="290"/>'+'</p></a></li>';
        //items += '<li data-icon="false"><a href="'+linkstr+'"><h2 class="ui-li-heading" style="white-space:normal">'+$content['page_title']+smalldesc+'</h2>'+'<p  style="white-space:normal">'+'<img src="'+photostr+'" width="290"/>'+'</p></a></li>';

        items +=
            '<li data-icon="false" class="">' + 
                '<a href="' + linkstr + '" data-article="' + $content['page_id'] + '" >' +
                    '<h2 class="ui-li-heading" style="white-space:normal">' + $content['page_title'] + '</h2>' +
                    '<p  class="text" style="white-space:normal">' +
                        '<img src="' + photostr + '" class="ui-li-thumb"/>' +
                        '<span class="date">' + $content['cnt_date'] + '</span><br />' +
                        smalldesc + 
                    '</p>' + 
                 '</a>' + 
            '</li>';

        counter += 1;
    }
    //$content = $.mobile.activePage.children( ":jqmData(role=content)" ).children (":first-child");
    //$content = $( "#home :jqmData(role=content)" ).children (":first-child");
    $content = $( "#home :jqmData(role=content) :first-child" );
    //alert ("LIST1" + $("#list1").is(":visible"));
    //alert ("LIST2" + $("#list2").is(":visible"));
    //$('#content li').remove();
    $content.html (items);
    $content.trigger ("create");
//    if ($content.is(":visible")) { $content.listview ('refresh'); }
//    $content.listview ('refresh');
    $content.listview().listview('refresh');
    app.info ('Home Content Loaded');
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.setCategories = function(data){
    app.info ('Set Categories Content');
    var level = 0;
    var counter = 0;
    //var items = '<li data-role="list-divider" role="heading">Κατηγορίες</li>';
    var items="";
    var page_title = "";
    while (counter< data.result.length){

        if(data.result[counter]['page_title'] == "athlitikes efimerides") data.result[counter]['page_title'] = "ΑΘΛΗΤΙΚΕΣ ΕΦΗΜΕΡΙΔΕΣ";
        if(data.result[counter]['page_title'] == "Αρθρογράφοι") data.result[counter]['page_title'] = "ΑΡΘΡΟΓΡΑΦΟΙ";
        if(data.result[counter]['page_title'] == "Κύπελλο Ελλάδας") data.result[counter]['page_title'] = "ΚΥΠΕΛΛΟ ΕΛΛΑΔΑΣ";
        if(data.result[counter]['page_title'] == "Προγνωστικά") data.result[counter]['page_title'] = "ΠΡΟΓΝΩΣΤΙΚΑ";
        if(data.result[counter]['page_title'] == "Τηλεοπτικές Μεταδόσεις") data.result[counter]['page_title'] = "ΤΗΛΕΟΠΤΙΚΕΣ ΜΕΤΑΔΟΣΕΙΣ";

//        items += '<li  data-theme="c"><a href="javascript:gotoUrl('+data.result[counter]['page_unique_id']+');">'+data.result[counter]['page_title']+'</a></li>';
        items += '<li data-theme="c"><a href="#category" data-category="' + data.result[counter]['page_unique_id'] + '" >'+data.result[counter]['page_title']+'</a></li>';
        counter+=1;
    }

    $content = $( "#categories :jqmData(role=content) :first-child" );
    $content.html(items);
    $content.trigger("create");
//    if ($content.is(":visible")) { $content.listview ('refresh'); }
    $content.listview ().listview ('refresh');
    app.info ('Categories Content Loaded');
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.setCategory = function (data) {
    app.info ('Set Category Content');
    var id = app.categoryId;

//    var level = 0;
//    var items = '<li data-role="list-divider" role="heading">Άρθρα</li>';

    var counter = 0;
    var items2 = '';
    var linkstr = '';

	var video = '';
	var pdf = '';
	var efimerida = '';
	var catphoto = '';
	var photo = '';
	var smalldesc = '';
	var photostr = '';
	var metadosistr = '';
	
	var tvdate = '';
	var cnt_date = '';
    var	imgstr = '';
    var tvdatestr = '';
    
    var currentTime = new Date();
    
    while (counter < data.result.length){
        
        video = data.result[counter]['youtubeid'];
        pdf = data.result[counter]['pdf'];
        efimerida = data.result[counter]['newspaper_photo'];
        catphoto = data.result[counter]['cat_photo'];
        photo = data.result[counter]['photo'];
        photostr = "";
		metadosistr = "";
		cnt_date = data.result[counter]['cnt_date'];
        smalldesc = data.result[counter]['page_description'];


        if(smalldesc == null){
        	smalldesc = "";
        } else {
            smalldesc = smalldesc.replace("<a href", "<a target='blank' href"); 
            //smalldesc = "<span class='smalldesc'>"+smalldesc+"</span>";
        }

        if(cnt_date == null){
        	cnt_date = "";
        }else{
//			cnt_date = "<span class='dimosieysi'><span class='lektika'>Δημοσίευση: </span>"+cnt_date+"</span>";
        }

//        linkstr = "javascript:gotopage("+data.result[counter]["page_id"]+")";
        linkstr = "#article";

        if(photo != ""){
            photostr = "http://www.pamesports.gr/thumbnail?filepath="+photo+"&width=160";
        }
        
        if(photo == null && efimerida != null){
            photostr = "http://www.pamesports.gr/thumbnail?filepath="+efimerida+"&width=160";
//            linkstr = "javascript:gotopage("+data.result[counter]["page_id"]+")";
            linkstr = "#article";
        }
        
        if(photo == null && video != null){
            photostr = "http://img.youtube.com/vi/"+video+"/hqdefault.jpg";
            linkstr = "javascript:window.plugins.childBrowser.openExternal('http://www.youtube.com/watch?v="+video+"')";
        }
        
        if(photo == "" && efimerida == "" && catphoto !=null){
            photostr = "http://www.pamesports.gr/thumbnail?filepath="+catphoto+"&width=160";
        }    
        
        //if(photo == "" && efimerida == "" && catphoto == null){
        //    photostr = "http://www.pamesports.gr/thumbnail?filepath="+catphoto+"&width=290";
        //}              
        
        if(pdf != null){
            photostr = "http://www.pamesports.gr/thumbnail?filepath="+photo+"&width=160";
            linkstr = "javascript:window.plugins.childBrowser.openExternal('http://www.pamesports.gr/"+pdf+"');";
        }        
                
        //show dates for tv
        if((data.result[counter]['tv_channel'] != null) && (data.result[counter]['tv_channel'] != "")) {
            linkstr = '#';
            if(data.result[counter]['tv_date'] != "0000-00-00"){
                tvdate = data.result[counter]['tv_date'];
                tvdate = new Date(Date.parse(tvdate,"yyyy-mm-dd"));
                tvdatestr = format2D(tvdate.getDate())+'-'+ format2D(tvdate.getMonth() + 1) +'-'+tvdate.getFullYear();
                metadosistr = "<div class='tvdate'>"+data.result[counter]['tv_channel']+"<br />"+tvdatestr+"  "+data.result[counter]['tv_time']+"</div>";
            }

        }

        if( (photo+efimerida+catphoto+video) == "") { imgstr = ''; }
        else { imgstr = '<img src="'+photostr+'" class="ui-li-thumb" width="160" />'; }

/*
        items +=
            '<li data-icon="false" class="">' + 
                '<a href="' + linkstr + '" data-article="' + $content['page_id'] + '" >' +
                    '<h2 class="ui-li-heading" style="white-space:normal">' + $content['page_title'] + '</h2>' +
                    '<p  style="white-space:normal">' +
                        '<img src="' + photostr + '" class="ui-li-thumb"/>' +
                        '<span class="date">' + $content['cnt_date'] + '</span><br />' +
                        smalldesc + 
                    '</p>' + 
                 '</a>' + 
            '</li>';
*/

        if(id == 5) { //arthrografoi
            items2 += '<li data-icon="false"><a href="'+linkstr+'" data-article="' + data.result[counter]["page_id"] + '"><h2 class="ui-li-heading" style="white-space:normal">'+data.result[counter]['page_title']+' <span class="arthrografos"><span class="lektika">Αρθρογράφος: </span>'+data.result[counter]['cat_title']+'</span>'+cnt_date+smalldesc+'</h2>'+'<p  style="white-space:normal">'+imgstr+metadosistr+'</p></a></li>';
        } else if(id == 90) { //tv metadosis
            if (tvdate.getDate() == currentTime.getDate()) {	//mono simerina	
                items2 += '<li data-icon="false"><a href="#"><h2 class="ui-li-heading" style="white-space:normal">'+data.result[counter]['page_title']+' <span class="arthrografos"><span class="lektika">Κατηγορία: </span>'+data.result[counter]['cat_title']+'</span>'+cnt_date+smalldesc+'</h2>'+'<p  style="white-space:normal">'+imgstr+metadosistr+'</p></a></li>';	
            }
        } else { //ola ta alla
/*            items2 +=   '<li data-icon="false">' + 
                            '<a href="'+linkstr+'" data-article="' + data.result[counter]["page_id"] + '">' + 
                                '<h2 class="ui-li-heading" style="white-space:normal">' +
                                    data.result[counter]['page_title'] +
                                    ' <span class="arthrografos"><span class="lektika">Κατηγορία: </span>'+data.result[counter]['cat_title']+'</span>' +
                                    cnt_date + 
                                '</h2>' +
                                '<p  style="white-space:normal">' +
                                    imgstr +
                                    metadosistr +
                                    smalldesc +
                                '</p>' + 
                            '</a>' +
                        '</li>';*/

            items2 +=   '<li data-icon="false">' + 
                            '<a href="'+linkstr+'" data-article="' + data.result[counter]["page_id"] + '">' + 
                                '<h2 class="ui-li-heading" style="white-space:normal">' +
                                    data.result[counter]['page_title'] +
                                '</h2>' +
                                '<p  style="white-space:normal">' +
                                    imgstr +
                                    '<span class="date">' + cnt_date + '</span><br />' +
                                    metadosistr +
                                    smalldesc +
                                '</p>' + 
                            '</a>' +
                        '</li>';
            //items2 += '<li data-icon="false"><a href="'+linkstr+'"><h2 class="ui-li-heading" style="white-space:normal">'+data.result[counter]['page_title']+smalldesc+'</h2>'+'<p class="ui-li-desc" style="white-space:normal">'+imgstr+metadosistr+'</p></a></li>';
        }
        counter+=1;
    }

/*
    $content = $( "#categories :jqmData(role=content) :first-child" );
    $content.html(items);
    $content.trigger("create");
    if ($content.is(":visible")) { $content.listview ('refresh'); }
    app.info ('Home Categories Loaded');
*/
//    $content = $( "#category :jqmData(role=content) :first-child" );
    $content = $('#category-content');

//    $('#contents li').remove();
    $content.html(items2);
//    $('#contents').html(items2);
    $content.trigger("create");
//    $('#contents').trigger("create");
//    if ($content.is(":visible")) { $content.listview ('refresh'); }
//    $content.listview('refresh');
    $content.listview('refresh');
    app.info ('Category Content Loaded');
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.setArticle = function (result) {
    app.info ('Set Article Content');

    if(result.result['page_title']) {
        $('#article_title').html("<h3>"+result.result['page_title']+"</h3>");
    }

//    $('#article_desc').html(result.result['page_content']);
//    var temp = $('#article_desc');
//    temp.html(temp.text());

    $html = $(app.decodeEntities (result.result['page_content']) );

    var newwidth = (window.innerWidth-35);
    var newheight = (window.innerHeight-40);

//    $("iframe").each(function(index, elem) {
    $html.find("iframe").each(function(index, elem) {
        if ($(this).attr('src').indexOf("/liveEvents/") != -1) { app.setLiveEvents ($(this) ); }
        else {
            elem.setAttribute("width", newwidth);
            elem.setAttribute("height", newheight);
        }
    });

//    $('img', $.mobile.activePage).each(function() {
    $html.find('img', $.mobile.activePage).each(function() {
        if ( ($src = $(this).attr('src') ) && ($src.substring(0, 12) == "/contentfile") ) {
            $(this).attr('src', 'http://www.pamesports.gr' + $src);
        }
    });

    $('#article_desc').empty().append($html);
    
    //set photo
    if(result.result['photo']) $('#article_photo').html('<img src="http://www.pamesports.gr/thumbnail?filepath='+ result.result['photo'] +'&width=290" align="left" style="padding:0px 10px 10px 0px;">');
    if(result.result['newspaper_photo']) $('#article_photo').html('<img class="newspaper_photo" src="http://www.pamesports.gr/thumbnail?filepath='+ result.result['newspaper_photo'] +'&width=290" align="left" style="width:100%; padding:0px 10px 10px 0px;">');
    if(result.result['youtubeid']) $('#article_video').html('<iframe class="youtube-player" type="text/html" width="280" height="194" src="http://www.youtube.com/embed/'+ result.result['youtubeid'] +'" frameborder="0"></iframe>');

    app.info ('Article Content Loaded');
};
// ------- End of Class Function Implementation -------------------------------------------------------

// ------- Class Function Implementation --------------------------------------------------------------
app.setLiveEvents = function($el) {
    app.info ('Set Live Events Content');
    $src = $el.attr ('src');
    $el.replaceWith( '<div id="commentsWrapper" />' );
    $.ajax({
        url: $src,
        success: function(result) {
            var $src="http://chat.pamesports.gr/liveEvents/js/scripts.js";
            result = result.replace($src,"/js/events.js");
//            result = result.replace('function popImage(',"function popImageOrig(");
            //result.replace(/http:\/\/chat.pamesports.gr\/liveEvents\/js\/scripts.js/g,"js/event.js");
/*
            $html.find('script[src]').each(function(){
                if ( $(this).attr('src').indexOf("/liveEvents/js/scripts.js") ) {
                    $(this).attr('src', 'js/event.js');
                }
            });
*/
            var $html = jQuery('<div>').html(result).find('#commentsWrapper');
            $('#commentsWrapper').append($html.contents());
        },
    });
};
// ------- End of Class Function Implementation -------------------------------------------------------

function format2D(somedigits){
	if(somedigits < 10) return "0"+somedigits;
	return somedigits;
}
